@@ -36,6 +36,7 @@ typedef enum {
 
 struct btd_device *device_create(DBusConnection *conn, struct btd_adapter *adapter,
 				const gchar *address);
+void device_set_name(struct btd_device *device, const char *name);
 void device_remove(struct btd_device *device, DBusConnection *conn,
 						gboolean remove_stored);
 gint device_address_cmp(struct btd_device *device, const gchar *address);
@@ -52,6 +53,7 @@ struct agent *device_get_agent(struct btd_device *device);
 void device_set_agent(struct btd_device *device, struct agent *agent);
 gboolean device_is_busy(struct btd_device *device);
 gboolean device_is_temporary(struct btd_device *device);
+gboolean device_is_paired(struct btd_device *device);
 void device_set_temporary(struct btd_device *device, gboolean temporary);
 void device_set_cap(struct btd_device *device, uint8_t cap);
 uint8_t device_get_cap(struct btd_device *device);
@@ -71,12 +73,23 @@ int device_request_authentication(struct btd_device *device, auth_type_t type,
 				uint32_t passkey, void *cb);
 void device_cancel_authentication(struct btd_device *device, gboolean aborted);
 gboolean device_is_authenticating(struct btd_device *device);
+gboolean device_is_authorizing(struct btd_device *device);
+void device_set_authorizing(struct btd_device *device, gboolean auth);
 void device_set_renewed_key(struct btd_device *device, gboolean renewed);
 void device_add_connection(struct btd_device *device, DBusConnection *conn,
 				uint16_t handle);
 void device_remove_connection(struct btd_device *device, DBusConnection *conn,
 				uint16_t handle);
 gboolean device_has_connection(struct btd_device *device, uint16_t handle);
+void device_disconnect(struct btd_device *device);
+
+typedef void (*disconnect_watch) (struct btd_device *device, gboolean removal,
+					void *user_data);
+
+guint device_add_disconnect_watch(struct btd_device *device,
+				disconnect_watch watch, void *user_data,
+				GDestroyNotify destroy);
+void device_remove_disconnect_watch(struct btd_device *device, guint id);
 
 #define BTD_UUIDS(args...) ((const char *[]) { args, NULL } )
 
@@ -89,3 +102,6 @@ struct btd_device_driver {
 
 int btd_register_device_driver(struct btd_device_driver *driver);
 void btd_unregister_device_driver(struct btd_device_driver *driver);
+
+struct btd_device *btd_device_ref(struct btd_device *device);
+void btd_device_unref(struct btd_device *device);
